# coding: utf-8
"""
sentry_redispubsub.forms
"""
from django import forms


class RedisPubSubOptionsForm(forms.Form):
    host = forms.CharField(
        max_length=255,
        help_text='Redis host (for example: "localhost")'
    )
    port = forms.IntegerField(
        max_value=65535,
        help_text='Redis port (for example: "6379")'
    )
    db = forms.IntegerField(
    	max_value=65535,
    	help_text='Redis db (for example: "0")'
    )
    channel_name = forms.CharField(
        max_length=255,
        help_text='Channel name for Sentry metrics to push to (for example: "sentry")'
    )



#!/usr/bin/env python
from setuptools import setup, find_packages

install_requires = [
    'sentry>=5.3.3',
    'redis',
]

f = open('README.rst')
readme = f.read()
f.close()

setup(
    name='sentry-redispubsub',
    version='0.0.1',
    author='Anthony Boah',
    author_email='anthony.boah@innogames.com',
    url='https://github.com/innogames/sentry-redispubsub',
    description='A Sentry extension which sends errors to a Redis pub/sub queue',
    long_description=readme,
    license='WTFPL',
    package_dir={'': 'src'},
    packages=find_packages('src'),
    install_requires=install_requires,
    entry_points={
        'sentry.plugins': [
            'redispubsub = sentry_redispubsub.plugin:RedisPubSubPlugin'
        ],
    },
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
        'Topic :: Software Development'
    ],
    keywords='sentry redis pubsub message queue msg',
)



# coding: utf-8
"""
sentry_redispubsub.plugin
"""

from sentry.plugins import Plugin

import sentry_redispubsub
from sentry_redispubsub.forms import RedisPubSubOptionsForm

import json
import redis
from time import mktime


class RedisPubSubPlugin(Plugin):
    """
    Sentry plugin to send errors stats to a Redis pub/sub message queue.
    """
    author = 'Anthony Boah'
    author_url = 'https://github.com/innogames/sentry-redispubsub'
    version = sentry_redispubsub.VERSION
    description = 'Send errors stats to a Redis pub/sub message queue.'
    slug = 'redispubsub'
    title = 'Redis Pub/Sub'
    conf_key = slug
    conf_title = title
    resource_links = [
        ('Source', 'https://github.com/innogames/sentry-redispubsub'),
        ('Bug Tracker', 'https://github.com/innogames/sentry-redispubsub/issues'),
        ('README', 'https://github.com/innogames/sentry-redispubsub/blob/master/README.rst'),
    ]
    project_conf_form = RedisPubSubOptionsForm

    def is_configured(self, project, **kwargs):
        """
        Check if plugin is configured.
        """
        params = self.get_option
        return bool(params('host', project) and params('port', project) and params('channel_name', project))

    def post_process(self, group, event, is_new, is_sample, **kwargs):
        """
        Process error.
        """
        if not self.is_configured(group.project):
            return

        host = self.get_option('host', group.project)
        port = self.get_option('port', group.project)
        db = self.get_option('db', group.project)
        channel_name = self.get_option('channel_name', group.project)

        metric = {}
        metric['project'] = group.project.slug
        metric['logger'] = group.logger
        metric['level'] = group.get_level_display()
        metric['msg'] = group.message
        metric['times_seen'] = group.times_seen
        metric['last_seen'] = mktime(group.last_seen.utctimetuple())
        metric['first_seen'] = mktime(group.first_seen.utctimetuple())
        metric['url'] = group.get_absolute_url()
        metric['checksum'] = group.checksum

        client = redis.StrictRedis(host, port, db)
        client.publish(channel_name, json.dumps(metric, sort_keys=False))